:orphan:

.. currentmodule:: obspy.core.util
.. automodule:: obspy.core.util
    :noindex:

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~attribdict.AttribDict
       ~base.NamedTemporaryFile
       ~base.create_empty_data_chunk
       ~base.get_example_file
       ~misc.BAND_CODE
       ~misc.complexify_string
       ~misc.guess_delta
       ~misc.score_at_percentile
       ~misc.to_int_or_zero
       ~obspy_types.Enum

    .. comment to end block


    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       attribdict
       base
       decorator
       misc
       obspy_types
       testing
       version

    .. comment to end block

